<config>
    <configuration>
        <interfaces>
            <interface>
                <name>{{ ml2_port_name }}</name>
                <unit delete="delete">
                    <name>0</name>
                </unit>
            </interface>
        </interfaces>
    </configuration>
</config>
