<config>
    <configuration>
        <vlans>
            <vlan>
                <name>{{ ml2_segmentation_name }}</name>
                <vlan-id>{{ ml2_segmentation_id }}</vlan-id>
            </vlan>
        </vlans>
    </configuration>
</config>
