<config>
    <configuration>
        <vlans>
            <vlan delete="delete">
                <name>{{ ml2_segmentation_name }}</name>
            </vlan>
        </vlans>
    </configuration>
</config>
